# generated by datamodel-codegen:
#   filename:  swagger.json
#   timestamp: 2023-03-19T19:24:29+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional

from pydantic import Field

import cherwell_pydantic_api.types as ct
from cherwell_pydantic_api.generated_api_utils import ApiBaseModel, HttpStatusCode


class DeleteApiClientSettingsResponse(ApiBaseModel):
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class GetApiClientSettingsResponseItem(ApiBaseModel):
    name: Optional[str] = None
    standInKey: Optional[str] = None


import cherwell_pydantic_api.types as ct


class ApiClientSettingResponse(ApiBaseModel):
    name: Optional[str] = None
    description: Optional[str] = None
    culture: Optional[str] = None
    clientKey: Optional[str] = None
    tokenLifespanMinutes: Optional[int] = None
    refreshTokenLifespanMinutes: Optional[int] = None
    apiAccessIsEnabled: Optional[bool] = None
    allowAnonymousAccess: Optional[bool] = None
    standInKey: Optional[str] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class ClientSecuritySettingsResponse(ApiBaseModel):
    internalLoginAllowed: Optional[bool] = None
    ldapLoginAllowed: Optional[bool] = None
    samlLoginAllowed: Optional[bool] = None
    windowsLoginAllowed: Optional[bool] = None


import cherwell_pydantic_api.types as ct


class MobileCredentialsModeResponse(ApiBaseModel):
    credentialsMode: Optional[int] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class Role(ApiBaseModel):
    browserClientCustomViewId: Optional[str] = None
    businessObjectExcludeList: Optional[List[str]] = None
    culture: Optional[str] = None
    description: Optional[str] = None
    mobileClientCustomViewId: Optional[str] = None
    primaryBusObId: Optional[ct.BusObID] = None
    roleId: Optional[str] = None
    roleName: Optional[str] = None
    smartClientCustomViewId: Optional[str] = None


import cherwell_pydantic_api.types as ct


class RoleReadV2Response(ApiBaseModel):
    roles: Optional[List[Role]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class FieldPermission(ApiBaseModel):
    departmentMemberEdit: Optional[bool] = None
    departmentMemberView: Optional[bool] = None
    edit: Optional[bool] = None
    fieldId: Optional[str] = None
    fieldName: Optional[str] = None
    managerOfOwnerEdit: Optional[bool] = None
    managerOfOwnerView: Optional[bool] = None
    ownerEdit: Optional[bool] = None
    ownerView: Optional[bool] = None
    teamEdit: Optional[bool] = None
    teamManagerOfOwnerEdit: Optional[bool] = None
    teamManagerOfOwnerView: Optional[bool] = None
    teamView: Optional[bool] = None
    view: Optional[bool] = None


import cherwell_pydantic_api.types as ct


class RightCategory(ApiBaseModel):
    categoryDescription: Optional[str] = None
    categoryId: Optional[str] = None
    categoryName: Optional[str] = None


import cherwell_pydantic_api.types as ct


class SecurityRightCategoriesResponse(ApiBaseModel):
    rightCategories: Optional[List[RightCategory]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class Right(ApiBaseModel):
    add: Optional[bool] = None
    allow: Optional[bool] = None
    categoryDescription: Optional[str] = None
    categoryId: Optional[str] = None
    categoryName: Optional[str] = None
    delete: Optional[bool] = None
    edit: Optional[bool] = None
    isYesNoRight: Optional[bool] = None
    nonScopeOwnerAdd: Optional[bool] = None
    nonScopeOwnerDelete: Optional[bool] = None
    nonScopeOwnerEdit: Optional[bool] = None
    nonScopeOwnerView: Optional[bool] = None
    rightId: Optional[str] = None
    rightName: Optional[str] = None
    standardRightName: Optional[str] = None
    viewRunOpen: Optional[bool] = None


import cherwell_pydantic_api.types as ct


class SecurityRightsResponse(ApiBaseModel):
    rights: Optional[List[Right]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class SecurityGroup(ApiBaseModel):
    description: Optional[str] = None
    groupId: Optional[str] = None
    groupName: Optional[str] = None


import cherwell_pydantic_api.types as ct


class SecurityGroupV2Response(ApiBaseModel):
    securityGroups: Optional[List[SecurityGroup]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class SaveApiClientSettingRequest(ApiBaseModel):
    allowAnonymousAccess: Optional[bool] = None
    apiAccessIsEnabled: Optional[bool] = None
    createNewClientKey: Optional[bool] = None
    culture: Optional[str] = None
    description: Optional[str] = None
    name: Optional[str] = None
    refreshTokenLifespanMinutes: Optional[int] = None
    standInKey: Optional[str] = None
    tokenLifespanMinutes: Optional[int] = None


import cherwell_pydantic_api.types as ct


class CloneSecurityGroupRequest(ApiBaseModel):
    securityGroupName: Optional[str] = None
    sourceSecurityGroupNameOrId: Optional[str] = None


import cherwell_pydantic_api.types as ct


class CloneSecurityGroupResponse(ApiBaseModel):
    securityGroupId: Optional[str] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class TokenResponse(ApiBaseModel):
    access_token: Optional[str] = None
    as_client_id: Optional[str] = Field(None, alias='as:client_id')
    field_expires: Optional[str] = Field(None, alias='.expires')
    expires_in: Optional[int] = None
    field_issued: Optional[str] = Field(None, alias='.issued')
    refresh_token: Optional[str] = None
    token_type: Optional[str] = None
    username: Optional[str] = None


import cherwell_pydantic_api.types as ct


class GetApiClientSettingsResponse(ApiBaseModel):
    settings: Optional[List[GetApiClientSettingsResponseItem]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class RoleReadResponse(ApiBaseModel):
    error: Optional[str] = None
    errorCode: Optional[str] = None
    hasError: Optional[bool] = None
    roles: Optional[List[Role]] = None


import cherwell_pydantic_api.types as ct


class BusinessObjectPermission(ApiBaseModel):
    busObId: Optional[ct.BusObID] = None
    busObName: Optional[str] = None
    departmentMemberEdit: Optional[bool] = None
    departmentMemberView: Optional[bool] = None
    edit: Optional[bool] = None
    fieldPermissions: Optional[List[FieldPermission]] = None
    managerOfOwnerEdit: Optional[bool] = None
    managerOfOwnerView: Optional[bool] = None
    ownerEdit: Optional[bool] = None
    ownerView: Optional[bool] = None
    teamEdit: Optional[bool] = None
    teamManagerOfOwnerEdit: Optional[bool] = None
    teamManagerOfOwnerView: Optional[bool] = None
    teamView: Optional[bool] = None
    view: Optional[bool] = None


import cherwell_pydantic_api.types as ct


class GetSecurityGroupBusinessObjectPermissionsResponse(ApiBaseModel):
    businessObjectPermissions: Optional[List[BusinessObjectPermission]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class SecurityGroupResponse(ApiBaseModel):
    securityGroups: Optional[List[SecurityGroup]] = None



# generated by datamodel-codegen:
#   filename:  swagger.json
#   timestamp: 2023-03-19T19:24:29+00:00

from __future__ import annotations

from datetime import datetime
from enum import Enum
from typing import List, Optional

import cherwell_pydantic_api.types as ct
from cherwell_pydantic_api.generated_api_utils import ApiBaseModel, HttpStatusCode

from . import Core


class FieldValidationError(ApiBaseModel):
    error: Optional[str] = None
    errorCode: Optional[str] = None
    fieldId: Optional[str] = None


import cherwell_pydantic_api.types as ct


class NotificationTrigger(ApiBaseModel):
    sourceType: Optional[str] = None
    sourceId: Optional[str] = None
    sourceChange: Optional[str] = None
    key: Optional[str] = None


import cherwell_pydantic_api.types as ct


class DeleteRequest(ApiBaseModel):
    busObId: Optional[ct.BusObID] = None
    busObPublicId: Optional[str] = None
    busObRecId: Optional[ct.BusObRecID] = None


import cherwell_pydantic_api.types as ct


class DeleteResponse(ApiBaseModel):
    busObId: Optional[ct.BusObID] = None
    busObPublicId: Optional[str] = None
    busObRecId: Optional[ct.BusObRecID] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class FieldTemplateItem(ApiBaseModel):
    dirty: Optional[bool] = None
    displayName: Optional[str] = None
    fieldId: Optional[str] = None
    fullFieldId: Optional[str] = None
    html: Optional[str] = None
    name: Optional[str] = None
    value: Optional[str] = None


import cherwell_pydantic_api.types as ct


class FieldValuesLookupRequest(ApiBaseModel):
    busbPublicId: Optional[str] = None
    busObId: Optional[ct.BusObID] = None
    busObRecId: Optional[ct.BusObRecID] = None
    fieldId: Optional[str] = None
    fieldName: Optional[str] = None
    fields: Optional[List[FieldTemplateItem]] = None


import cherwell_pydantic_api.types as ct


class FieldValuesLookupResponse(ApiBaseModel):
    values: Optional[List[str]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class BusObActivity(ApiBaseModel):
    id: Optional[str] = None
    parentBusObDefId: Optional[str] = None
    parentBusObRecId: Optional[ct.BusObRecID] = None
    historyBusObDefId: Optional[str] = None
    historyBusObRecId: Optional[ct.BusObRecID] = None
    type: Optional[str] = None
    title: Optional[str] = None
    body: Optional[str] = None
    createdBy: Optional[str] = None
    created: Optional[datetime] = None
    modified: Optional[datetime] = None
    modifiedBy: Optional[str] = None


class AttachmentType(Enum):
    Imported = 'Imported'
    Linked = 'Linked'
    URL = 'URL'


class Scope(Enum):
    None_ = 'None'
    Global = 'Global'
    Team = 'Team'
    Persona = 'Persona'
    SecurityGroup = 'SecurityGroup'
    User = 'User'
    UserInPersona = 'UserInPersona'
    OtherUsers = 'OtherUsers'
    Core = 'Core'
    BusIntel = 'BusIntel'
    FromResource = 'FromResource'
    Site = 'Site'
    Custom = 'Custom'
    BusObRecord = 'BusObRecord'


class Type(Enum):
    None_ = 'None'
    File = 'File'
    FileManagerFile = 'FileManagerFile'
    BusOb = 'BusOb'
    History = 'History'
    Other = 'Other'
    Solution = 'Solution'
    UsedAsSolution = 'UsedAsSolution'
    ExternalSolution = 'ExternalSolution'


import cherwell_pydantic_api.types as ct


class Attachment(ApiBaseModel):
    attachedBusObId: Optional[ct.BusObID] = None
    attachedBusObRecId: Optional[ct.BusObRecID] = None
    attachmentFileId: Optional[str] = None
    attachmentFileName: Optional[str] = None
    attachmentFileType: Optional[str] = None
    attachmentId: Optional[str] = None
    attachmentType: Optional[AttachmentType] = None
    busObId: Optional[ct.BusObID] = None
    busObRecId: Optional[ct.BusObRecID] = None
    comment: Optional[str] = None
    created: Optional[datetime] = None
    displayText: Optional[str] = None
    links: Optional[List[Core.CherwellLink]] = None
    owner: Optional[str] = None
    scope: Optional[Scope] = None
    scopeOwner: Optional[str] = None
    type: Optional[Type] = None


import cherwell_pydantic_api.types as ct


class AttachmentsRequest(ApiBaseModel):
    attachmentId: Optional[str] = None
    attachmentTypes: Optional[List[AttachmentType]] = None
    busObId: Optional[ct.BusObID] = None
    busObName: Optional[str] = None
    busObPublicId: Optional[str] = None
    busObRecId: Optional[ct.BusObRecID] = None
    includeLinks: Optional[bool] = None
    types: Optional[List[Type]] = None


import cherwell_pydantic_api.types as ct


class ReadRequest(ApiBaseModel):
    busObId: Optional[ct.BusObID] = None
    busObPublicId: Optional[str] = None
    busObRecId: Optional[ct.BusObRecID] = None


import cherwell_pydantic_api.types as ct


class BarcodeLookupResponse(ApiBaseModel):
    busObId: Optional[ct.BusObID] = None
    busObRecId: Optional[ct.BusObRecID] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class FieldDefinition(ApiBaseModel):
    autoFill: Optional[bool] = None
    calculated: Optional[bool] = None
    category: Optional[str] = None
    decimalDigits: Optional[int] = None
    description: Optional[str] = None
    details: Optional[str] = None
    displayName: Optional[str] = None
    enabled: Optional[bool] = None
    fieldId: Optional[str] = None
    hasDate: Optional[bool] = None
    hasTime: Optional[bool] = None
    isFullTextSearchable: Optional[bool] = None
    maximumSize: Optional[str] = None
    name: Optional[str] = None
    readOnly: Optional[bool] = None
    required: Optional[bool] = None
    type: Optional[str] = None
    typeLocalized: Optional[str] = None
    validated: Optional[bool] = None
    wholeDigits: Optional[int] = None


import cherwell_pydantic_api.types as ct


class GridDefinition(ApiBaseModel):
    gridId: Optional[str] = None
    name: Optional[str] = None
    displayName: Optional[str] = None


import cherwell_pydantic_api.types as ct


class Relationship(ApiBaseModel):
    cardinality: Optional[str] = None
    description: Optional[str] = None
    displayName: Optional[str] = None
    fieldDefinitions: Optional[List[FieldDefinition]] = None
    relationshipId: Optional[str] = None
    target: Optional[str] = None


import cherwell_pydantic_api.types as ct


class Summary(ApiBaseModel):
    firstRecIdField: Optional[str] = None
    groupSummaries: Optional[List[Summary]] = None
    recIdFields: Optional[str] = None
    stateFieldId: Optional[str] = None
    states: Optional[str] = None
    busObId: Optional[ct.BusObID] = None
    displayName: Optional[str] = None
    group: Optional[bool] = None
    lookup: Optional[bool] = None
    major: Optional[bool] = None
    name: Optional[str] = None
    supporting: Optional[bool] = None


import cherwell_pydantic_api.types as ct


class TemplateRequest(ApiBaseModel):
    busObId: Optional[ct.BusObID] = None
    fieldNames: Optional[List[str]] = None
    fieldIds: Optional[List[str]] = None
    includeAll: Optional[bool] = None
    includeRequired: Optional[bool] = None


import cherwell_pydantic_api.types as ct


class TemplateResponse(ApiBaseModel):
    fields: Optional[List[FieldTemplateItem]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class ViewSummary(ApiBaseModel):
    groupSummaries: Optional[List[ViewSummary]] = None
    image: Optional[str] = None
    isPartOfView: Optional[bool] = None
    busObId: Optional[ct.BusObID] = None
    displayName: Optional[str] = None
    group: Optional[bool] = None
    lookup: Optional[bool] = None
    major: Optional[bool] = None
    name: Optional[str] = None
    supporting: Optional[bool] = None


import cherwell_pydantic_api.types as ct


class SaveBusObAttachmentRequest(ApiBaseModel):
    attachBusObId: Optional[ct.BusObID] = None
    attachBusObName: Optional[str] = None
    attachBusObPublicId: Optional[str] = None
    attachBusObRecId: Optional[ct.BusObRecID] = None
    busObId: Optional[ct.BusObID] = None
    busObName: Optional[str] = None
    busObPublicId: Optional[str] = None
    busObRecId: Optional[ct.BusObRecID] = None
    comment: Optional[str] = None
    includeLinks: Optional[bool] = None


import cherwell_pydantic_api.types as ct


class SaveLinkAttachmentRequest(ApiBaseModel):
    busObId: Optional[ct.BusObID] = None
    busObName: Optional[str] = None
    busObPublicId: Optional[str] = None
    busObRecId: Optional[ct.BusObRecID] = None
    comment: Optional[str] = None
    displayText: Optional[str] = None
    includeLinks: Optional[bool] = None
    uncFilePath: Optional[str] = None


import cherwell_pydantic_api.types as ct


class SaveUrlAttachmentRequest(ApiBaseModel):
    busObId: Optional[ct.BusObID] = None
    busObName: Optional[str] = None
    busObPublicId: Optional[str] = None
    busObRecId: Optional[ct.BusObRecID] = None
    comment: Optional[str] = None
    displayText: Optional[str] = None
    includeLinks: Optional[bool] = None
    url: Optional[str] = None


class CacheScope(Enum):
    Tenant = 'Tenant'
    User = 'User'
    Session = 'Session'


import cherwell_pydantic_api.types as ct


class SaveRequest(ApiBaseModel):
    busObId: Optional[ct.BusObID] = None
    busObPublicId: Optional[str] = None
    busObRecId: Optional[ct.BusObRecID] = None
    cacheKey: Optional[str] = None
    cacheScope: Optional[CacheScope] = None
    fields: Optional[List[FieldTemplateItem]] = None
    persist: Optional[bool] = None


import cherwell_pydantic_api.types as ct


class RelatedSaveRequest(ApiBaseModel):
    parentBusObId: Optional[ct.BusObID] = None
    parentBusObPublicId: Optional[str] = None
    parentBusObRecId: Optional[ct.BusObRecID] = None
    relationshipId: Optional[str] = None
    busObId: Optional[ct.BusObID] = None
    busObPublicId: Optional[str] = None
    busObRecId: Optional[ct.BusObRecID] = None
    cacheKey: Optional[str] = None
    cacheScope: Optional[CacheScope] = None
    fields: Optional[List[FieldTemplateItem]] = None
    persist: Optional[bool] = None


import cherwell_pydantic_api.types as ct


class RelatedSaveResponse(ApiBaseModel):
    parentBusObId: Optional[ct.BusObID] = None
    parentBusObPublicId: Optional[str] = None
    parentBusObRecId: Optional[ct.BusObRecID] = None
    relationshipId: Optional[str] = None
    busObPublicId: Optional[str] = None
    busObRecId: Optional[ct.BusObRecID] = None
    cacheKey: Optional[str] = None
    fieldValidationErrors: Optional[List[FieldValidationError]] = None
    notificationTriggers: Optional[List[NotificationTrigger]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class SaveResponse(ApiBaseModel):
    busObPublicId: Optional[str] = None
    busObRecId: Optional[ct.BusObRecID] = None
    cacheKey: Optional[str] = None
    fieldValidationErrors: Optional[List[FieldValidationError]] = None
    notificationTriggers: Optional[List[NotificationTrigger]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class BatchDeleteRequest(ApiBaseModel):
    deleteRequests: Optional[List[DeleteRequest]] = None
    stopOnError: Optional[bool] = None


import cherwell_pydantic_api.types as ct


class BatchDeleteResponse(ApiBaseModel):
    responses: Optional[List[DeleteResponse]] = None


import cherwell_pydantic_api.types as ct


class ReadResponse(ApiBaseModel):
    busObId: Optional[ct.BusObID] = None
    busObPublicId: Optional[str] = None
    busObRecId: Optional[ct.BusObRecID] = None
    fields: Optional[List[FieldTemplateItem]] = None
    links: Optional[List[Core.CherwellLink]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class AttachmentsResponse(ApiBaseModel):
    attachments: Optional[List[Attachment]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class BatchReadRequest(ApiBaseModel):
    readRequests: Optional[List[ReadRequest]] = None
    stopOnError: Optional[bool] = None


import cherwell_pydantic_api.types as ct


class BatchReadResponse(ApiBaseModel):
    responses: Optional[List[ReadResponse]] = None


import cherwell_pydantic_api.types as ct


class SchemaResponse(ApiBaseModel):
    busObId: Optional[ct.BusObID] = None
    fieldDefinitions: Optional[List[FieldDefinition]] = None
    firstRecIdField: Optional[str] = None
    gridDefinitions: Optional[List[GridDefinition]] = None
    name: Optional[str] = None
    recIdFields: Optional[str] = None
    relationships: Optional[List[Relationship]] = None
    stateFieldId: Optional[str] = None
    states: Optional[str] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class BusObsForViewResponse(ApiBaseModel):
    summaries: Optional[List[ViewSummary]] = None


import cherwell_pydantic_api.types as ct


class BatchSaveRequest(ApiBaseModel):
    saveRequests: Optional[List[SaveRequest]] = None
    stopOnError: Optional[bool] = None


import cherwell_pydantic_api.types as ct


class BatchSaveResponse(ApiBaseModel):
    responses: Optional[List[SaveResponse]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


Summary.update_forward_refs()
ViewSummary.update_forward_refs()



# generated by datamodel-codegen:
#   filename:  swagger.json
#   timestamp: 2023-03-19T19:24:29+00:00

from __future__ import annotations

from datetime import datetime
from enum import Enum
from typing import Dict, List, Optional

import cherwell_pydantic_api.types as ct
from cherwell_pydantic_api.generated_api_utils import ApiBaseModel

from .... import CherwellObjectID
from ... import CherwellNameValuePair


class CherwellLink(ApiBaseModel):
    name: Optional[str] = None
    url: Optional[str] = None


import cherwell_pydantic_api.types as ct
from cherwell_pydantic_api.generated_api_utils import HttpStatusCode


class ManagerItem(ApiBaseModel):
    association: Optional[str] = None
    description: Optional[str] = None
    displayName: Optional[str] = None
    galleryImage: Optional[str] = None
    id: Optional[str] = None
    links: Optional[List[CherwellLink]] = None
    localizedScopeName: Optional[str] = None
    name: Optional[str] = None
    parentFolder: Optional[str] = None
    parentIsScopeFolder: Optional[bool] = None
    scope: Optional[str] = None
    scopeOwner: Optional[str] = None
    standInKey: Optional[str] = None


class StoredValueType(Enum):
    Text = 'Text'
    Number = 'Number'
    DateTime = 'DateTime'
    Logical = 'Logical'
    Color = 'Color'
    Json = 'Json'
    JsonArray = 'JsonArray'
    Xml = 'Xml'
    XmlCollection = 'XmlCollection'


import cherwell_pydantic_api.types as ct


class StoredValueResponse(ApiBaseModel):
    description: Optional[str] = None
    folder: Optional[str] = None
    id: Optional[str] = None
    name: Optional[str] = None
    scope: Optional[str] = None
    scopeOwner: Optional[str] = None
    standInKey: Optional[str] = None
    storedValueType: Optional[StoredValueType] = None
    value: Optional[str] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class View(ApiBaseModel):
    name: Optional[str] = None
    viewId: Optional[str] = None
    image: Optional[str] = None


class Level(Enum):
    Fatal = 'Fatal'
    Error = 'Error'
    Warning = 'Warning'
    Info = 'Info'
    Stats = 'Stats'
    Debug = 'Debug'


import cherwell_pydantic_api.types as ct


class LogRequest(ApiBaseModel):
    keyValueProperties: Optional[List[CherwellObjectID]] = None
    level: Optional[Level] = None
    message: Optional[str] = None


class ImageType(Enum):
    Imported = 'Imported'
    File = 'File'
    Url = 'Url'


import cherwell_pydantic_api.types as ct


class SaveGalleryImageRequest(ApiBaseModel):
    base64EncodedImageData: Optional[str] = None
    description: Optional[str] = None
    folder: Optional[str] = None
    imageType: Optional[ImageType] = None
    name: Optional[str] = None
    scope: Optional[str] = None
    scopeOwner: Optional[str] = None
    standInKey: Optional[str] = None


import cherwell_pydantic_api.types as ct


class SaveGalleryImageResponse(ApiBaseModel):
    name: Optional[str] = None
    standInKey: Optional[str] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class SaveStoredValueRequest(ApiBaseModel):
    description: Optional[str] = None
    folder: Optional[str] = None
    name: Optional[str] = None
    scope: Optional[str] = None
    scopeOwner: Optional[str] = None
    standInKey: Optional[str] = None
    storedValueType: Optional[StoredValueType] = None
    value: Optional[str] = None


class ActionType(Enum):
    None_ = 'None'
    OneStep = 'OneStep'
    Command = 'Command'
    BuiltIn = 'BuiltIn'
    Category = 'Category'
    SearchGrp = 'SearchGrp'
    Report = 'Report'
    Dashboard = 'Dashboard'
    Calendar = 'Calendar'
    Visualization = 'Visualization'
    Group = 'Group'
    Page = 'Page'
    DocRepository = 'DocRepository'
    PortalCommand = 'PortalCommand'
    ActionCatalog = 'ActionCatalog'
    OneStepForRecord = 'OneStepForRecord'


class LoginEnabledMode(Enum):
    Anonymous = 'Anonymous'
    LoggedIn = 'LoggedIn'
    Both = 'Both'


class LoginVisibilityMode(Enum):
    Anonymous = 'Anonymous'
    LoggedIn = 'LoggedIn'
    Both = 'Both'


import cherwell_pydantic_api.types as ct


class Action(ApiBaseModel):
    actionCommand: Optional[str] = None
    actionType: Optional[ActionType] = None
    alwaysTextAndImage: Optional[bool] = None
    beginGroup: Optional[bool] = None
    childActions: Optional[List[Action]] = None
    dependencies: Optional[List[str]] = None
    displayText: Optional[str] = None
    enabled: Optional[bool] = None
    galleryImage: Optional[str] = None
    helpText: Optional[str] = None
    loginEnabledMode: Optional[LoginEnabledMode] = None
    loginVisibilityMode: Optional[LoginVisibilityMode] = None
    name: Optional[str] = None
    parameters: Optional[Dict[str, str]] = None
    visible: Optional[bool] = None


import cherwell_pydantic_api.types as ct


class Location(ApiBaseModel):
    altitude: Optional[float] = None
    busObId: Optional[ct.BusObID] = None
    busObRecId: Optional[ct.BusObRecID] = None
    latitude: Optional[float] = None
    longitude: Optional[float] = None


import cherwell_pydantic_api.types as ct


class SimplePromptValue(ApiBaseModel):
    promptDefId: Optional[str] = None
    promptName: Optional[str] = None
    value: Optional[str] = None


import cherwell_pydantic_api.types as ct


class PromptValue(ApiBaseModel):
    busObId: Optional[ct.BusObID] = None
    collectionStoreEntireRow: Optional[str] = None
    collectionValueField: Optional[str] = None
    fieldId: Optional[str] = None
    listReturnFieldId: Optional[str] = None
    promptId: Optional[str] = None
    value: Optional[CherwellObjectID] = None
    valueIsRecId: Optional[bool] = None


class ListDisplayOption(Enum):
    Auto = 'Auto'
    Text = 'Text'
    Combo = 'Combo'
    GridList = 'GridList'
    SimpleList = 'SimpleList'
    PromptSimpleGrid = 'PromptSimpleGrid'


class PromptType(Enum):
    None_ = 'None'
    Text = 'Text'
    Number = 'Number'
    DateTime = 'DateTime'
    Logical = 'Logical'
    Binary = 'Binary'
    DateOnly = 'DateOnly'
    TimeOnly = 'TimeOnly'
    Json = 'Json'
    JsonArray = 'JsonArray'
    Xml = 'Xml'
    XmlCollection = 'XmlCollection'
    TimeValue = 'TimeValue'


import cherwell_pydantic_api.types as ct


class Prompt(ApiBaseModel):
    allowValuesOnly: Optional[bool] = None
    busObId: Optional[ct.BusObID] = None
    collectionStoreEntireRow: Optional[str] = None
    collectionValueField: Optional[str] = None
    constraintXml: Optional[str] = None
    contents: Optional[str] = None
    default: Optional[str] = None
    fieldId: Optional[str] = None
    isDateRange: Optional[bool] = None
    listDisplayOption: Optional[ListDisplayOption] = None
    listReturnFieldId: Optional[str] = None
    multiLine: Optional[bool] = None
    promptId: Optional[str] = None
    promptType: Optional[PromptType] = None
    promptTypeName: Optional[str] = None
    required: Optional[bool] = None
    text: Optional[str] = None
    value: Optional[CherwellObjectID] = None
    values: Optional[List[str]] = None


import cherwell_pydantic_api.types as ct


class ServiceInfoResponse(ApiBaseModel):
    apiVersion: Optional[str] = None
    csmCulture: Optional[str] = None
    csmVersion: Optional[str] = None
    systemDateTime: Optional[datetime] = None
    timeZone: Optional[CherwellObjectID] = None
    systemUtcOffset: Optional[str] = None


import cherwell_pydantic_api.types as ct


class ManagerFolder(ApiBaseModel):
    association: Optional[str] = None
    childFolders: Optional[List[ManagerFolder]] = None
    childItems: Optional[List[ManagerItem]] = None
    id: Optional[str] = None
    links: Optional[List[CherwellLink]] = None
    localizedScopeName: Optional[str] = None
    name: Optional[str] = None
    parentId: Optional[str] = None
    scope: Optional[str] = None
    scopeOwner: Optional[str] = None


import cherwell_pydantic_api.types as ct


class ViewsResponse(ApiBaseModel):
    views: Optional[List[View]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


import cherwell_pydantic_api.types as ct


class LogBatchRequest(ApiBaseModel):
    logRequests: Optional[List[LogRequest]] = None


import cherwell_pydantic_api.types as ct


class ManagerData(ApiBaseModel):
    root: Optional[ManagerFolder] = None
    supportedAssociations: Optional[List[CherwellNameValuePair]] = None
    errorCode: Optional[str] = None
    errorMessage: Optional[str] = None
    hasError: Optional[bool] = None
    httpStatusCode: Optional[HttpStatusCode] = None


Action.update_forward_refs()
ManagerFolder.update_forward_refs()



import re
from typing import Optional

from pydantic import AnyHttpUrl, BaseSettings, DirectoryPath, Field, SecretStr, validator



class InstanceSettingsBase(BaseSettings):
    name: str = Field(default='_unset')
    base_url: Optional[AnyHttpUrl] = Field(default=None)
    client_id: SecretStr = Field(default='')
    username: str = Field(default='')
    password: SecretStr = Field(default='')
    timeout: float = Field(default=0.0)


class InstanceSettings(InstanceSettingsBase):
    pass


class Settings(InstanceSettingsBase):
    name: str = 'default'
    inst: dict[str, InstanceSettings] = Field(default={})
    model_dir: DirectoryPath = Field(default='models')
    
    _re_inst_name = re.compile(r'^[a-z][a-z0-9]+$')

    def get_instance(self, instance_name: Optional[str] = None) -> Optional[InstanceSettingsBase]:
        """Return the instance settings for the given instance, or the default settings if instance_name is None or 'default'"""
        if instance_name is None or instance_name == self.name:
            return self
        return self.inst.get(instance_name, None)
    
    @validator('inst')
    def validate_inst(cls, v):
        for inst_name, inst in v.items():
            if not cls._re_inst_name.match(inst_name) or inst_name == 'default':
                raise ValueError(f"Invalid instance name: {inst_name}")
        return v
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self._fixup()

    def _fixup(self):
        """After instantiation, propagate the default values to the instances."""
        for inst_name, inst in self.inst.items():
            if inst.name != '_unset':
                raise ValueError("Don't specify the instance name in the instance settings")
            inst.name = inst_name
            if not inst.base_url:
                inst.base_url = self.base_url
            if not inst.client_id:
                inst.client_id = self.client_id
            if not inst.username:
                inst.username = self.username
            if not inst.password:
                inst.password = self.password
            if not inst.timeout:
                inst.timeout = self.timeout


    class Config:
        env_file = ['cherwell.env']
        env_file_encoding = 'utf-8'
        env_prefix = 'cherwell_'
        env_nested_delimiter = '__'



if __name__ == '__main__':
    print(Settings().dict())
